=======
History
=======

0.2.1 (2024-11-08)
------------------

* Fixed types of arguments.


0.2.0 (2024-10-16)
------------------

* Added the ``--bootstrap_edges`` flag, which allows specifying the percentage of edges to be randomly removed
  from each PPI network (across networks at different PPI cutoffs).

* Added a style for proteins specified as bait.

* Refactored code and expose more methods for hierarchy generation from edgelists.


0.1.0 (2024-09-06)
------------------

* First release on PyPI.
